==> libbpp-seq-omics_2.1.0.orig.tar.gz: bpp-seq-omics-2.1.0/src/Bpp/Seq/Io/Maf/IterationListener.cpp <==
//
// File: IterationListener.cpp
// Authors: Julien Dutheil
// Created: Wed Jun 27 2012
//

/*
Copyright or © or Copr. Bio++ Development Team, (2012)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "IterationListener.h"

// From the STL:
#include <vector>

using namespace std;
using namespace bpp;

void CsvStatisticsOutputIterationListener::iterationStarts()
{
  const vector<string>& header = statsIterator_->getResultsColumnNames();
  *output_ << "Chr" << sep_ << "Start" << sep_ << "Stop";
  for (size_t i = 0; i < header.size(); ++i) {
    *output_ << sep_ << header[i];
  }
  output_->endLine();
}

void CsvStatisticsOutputIterationListener::iterationMoves(const MafBlock& currentBlock)
{
  const vector<double>& values = statsIterator_->getResults();
  if (currentBlock.hasSequenceForSpecies(refSpecies_)) {
    const MafSequence& refSeq = currentBlock.getSequenceForSpecies(refSpecies_);
    if (refSeq.hasCoordinates()) 
      *output_ << refSeq.getChromosome() << sep_ << refSeq.start() << sep_ << refSeq.stop();
    else
      *output_ << "NA" << sep_ << "NA" << sep_ << "NA";
  } else {
    *output_ << "NA" << sep_ << "NA" << sep_ << "NA";
  }
  for (size_t i = 0; i < values.size(); ++i) {
    *output_ << sep_ << values[i];
  }
  output_->endLine();
}

==> libbpp-seq-omics_2.4.1.orig.tar.gz: bpp-seq-omics-2.4.1/src/Bpp/Seq/Io/Maf/IterationListener.cpp <==
//
// File: IterationListener.cpp
// Authors: Julien Dutheil
// Created: Wed Jun 27 2012
//

/*
Copyright or © or Copr. Bio++ Development Team, (2012)

This software is a computer program whose purpose is to provide classes
for sequences analysis.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include "IterationListener.h"

// From the STL:
#include <vector>

using namespace std;
using namespace bpp;

void CsvStatisticsOutputIterationListener::iterationStarts()
{
  const vector<string>& header = statsIterator_->getResultsColumnNames();
  *output_ << "Chr" << sep_ << "Start" << sep_ << "Stop";
  for (size_t i = 0; i < header.size(); ++i) {
    *output_ << sep_ << header[i];
  }
  output_->endLine();
}

void CsvStatisticsOutputIterationListener::iterationMoves(const MafBlock& currentBlock)
{
  const vector<const BppNumberI*>& values = statsIterator_->getResults();
  if (currentBlock.hasSequenceForSpecies(refSpecies_)) {
    const MafSequence& refSeq = currentBlock.getSequenceForSpecies(refSpecies_);
    if (refSeq.hasCoordinates()) 
      *output_ << refSeq.getChromosome() << sep_ << refSeq.start() << sep_ << refSeq.stop();
    else
      *output_ << "NA" << sep_ << "NA" << sep_ << "NA";
  } else {
    *output_ << "NA" << sep_ << "NA" << sep_ << "NA";
  }
  for (size_t i = 0; i < values.size(); ++i) {
    *output_ << sep_ << (values[i] ? values[i]->toString() : "NA");
    //Memory cleaning:
    if (values[i]) delete values[i];
  }
  output_->endLine();
}
